@@ -1,10 +1,10 @@
-fractional_cover <- function(veg.PI, ground_fractional="FALSE", in_canopy_sky="FALSE") {
+fractional_cover <- function(veg.PI, ground_fractional=FALSE, in_canopy_sky=FALSE) {
 	
 	hits <- veg.PI #to match the raw input to historical label in below
 	
 	
 	
-	if(ground_fractional == "FALSE") {
+	if(!ground_fractional) {
 		
 
 	
@@ -14,7 +14,7 @@ fractional_cover <- function(veg.PI, ground_fractional="FALSE", in_canopy_sky="F
 	for(i in 1:nrow(hits)) { #a
 		n <- n + 1
 		temp <- hits[n,]
-		if(is.na(temp$growth_form) | temp$in_canopy_sky && in_canopy_sky == "FALSE") { #b
+		if(is.na(temp$growth_form) | temp$in_canopy_sky && !in_canopy_sky) { #b
 			if(temp$substrate %in% c("Litter", "CWD", "Crypto")) { #c
 				fraction[n] <- "brown"
 			} #/c
@@ -72,7 +72,10 @@ fractional_cover_output <- fractional_df_sites[,c(1,2,5)]
 names(fractional_cover_output) <- c("Plot", "Fraction", "Percent") #these names are not returned in the output - just formatting for matrix conversion
 fractional_cover_output$Percent <- round(fractional_cover_output$Percent, digits=2)
 
-#create a matrix version to condense the data, columns are fractions, rows are plots:
+##create a matrix version to condense the data, columns are fractions, rows are plots:
+#change NAs for fraction to 'other'
+fractional_cover_output$Fraction <- as.character(fractional_cover_output$Fraction) #needed working in R v3 where this may be a factor for which you can't add values that aren't existing levels
+fractional_cover_output$Fraction[is.na(fractional_cover_output$Fraction)] <- "other"
 fractional_cover_output.matrix <- ma_ausplot_ma(fractional_cover_output)
 fractional_cover_output.matrix$site_unique <- row.names(fractional_cover_output.matrix)
 
@@ -80,6 +83,8 @@ COL <- ncol(fractional_cover_output.matrix)
 
 fractional_cover_output.matrix <- fractional_cover_output.matrix[,c(COL, 1:COL-1)]
 
+fractional_cover_output.matrix[,c(2:5)] <- round(fractional_cover_output.matrix[,c(2:5)], digits=1)
+
 return(fractional_cover_output.matrix)
 
 	} #close ground fractional false
@@ -88,7 +93,7 @@ return(fractional_cover_output.matrix)
 
 #Calculate fractional GROUND cover
 
-if(ground_fractional == "TRUE") {
+if(ground_fractional) {
 	
 	n <- 0
 	ground.fraction <- rep(NA, nrow(hits))
@@ -148,12 +153,17 @@ names(ground.fractional.output) <- c("Plot", "Fraction", "Percent") #these names
 ground.fractional.output$Percent <- round(ground.fractional.output$Percent, digits=2)
 
 #generate a matrix to condense the data - columns are fractions and rows are plots
+#change NAs for fraction to 'other'
+ground.fractional.output$Fraction <- as.character(ground.fractional.output$Fraction) #needed working in R v3 where this may be a factor for which you can't add values that aren't existing levels
+ground.fractional.output$Fraction[is.na(ground.fractional.output$Fraction)] <- "other"
 ground.fractional.output.matrix <- ma_ausplot_ma(ground.fractional.output)
 
 ground.fractional.output.matrix$site_unique <- row.names(ground.fractional.output.matrix)
 
 ground.fractional.output.matrix <- ground.fractional.output.matrix[,c(5,1,2,3,4)]
 
+ground.fractional.output.matrix[,c(2:5)] <- round(ground.fractional.output.matrix[,c(2:5)], digits=1)
+
 return(ground.fractional.output.matrix)
 
 
