@@ -3,12 +3,9 @@ map_attribute <- function(my.ausplots.object) {
 	
 		if(any(c("Tree/Palm", "Tree Mallee") %in% my.ausplots.object$veg.PI$growth_form)) {
 		
-		aus <- maps::map("worldHires", "Australia", fill=TRUE, xlim=c(110,160),ylim=c(-45,-5), mar=c(0,0,0,0), plot=FALSE)
-	
-	#CRS("+init=epsg:4326") # More info (i.e. provides a datum)
-	aus.sp <-  maptools::map2SpatialPolygons(aus, IDs=aus$names, proj4string=CRS("+init=epsg:4326"))
-	
-	my.ausplots.object$site.info$bioregion.f <- factor(my.ausplots.object$site.info$bioregion_name)
+		  aus.sp <- ggplot2::map_data("world2Hires", "Australia")
+		  
+		  my.ausplots.object$site.info$bioregion.f <- factor(my.ausplots.object$site.info$bioregion_name)
 	
 	#get tree cover
 	tree_cover <- single_cover_value(my.ausplots.object$veg.PI)
@@ -16,8 +13,10 @@ map_attribute <- function(my.ausplots.object) {
 		names(tree_cover)[names(tree_cover) %in% "percentCover"] <- "Tree_cover"
 	
 	####
-	the_map <- ggplot(data = tree_cover, aes(x = longitude, y = latitude, group = bioregion.f), alpha = 0.5) + 
+
+	the_map <- ggplot2::ggplot(data = tree_cover, aes(x = longitude, y = latitude, group = bioregion.f), alpha = 0.5) + 
 	         geom_polygon(data=fortify(aus.sp), aes(x=long, y=lat, group=group), col="black", fill="seashell") +
+      	  coord_sf(xlim=c(110, 160), ylim=c(-45,-10), expand=TRUE, crs= "+proj=longlat +ellps=clrk66 +no_defs +type=crs") +
 		     #geom_point(aes(colour=bioregion.f, fill=bioregion.f, size=Tree_cover)) + 
 	        geom_point(aes(size=Tree_cover), shape=1, colour = "darkgreen") + 
 		     ggtitle("AusPlots locations with tree cover") + 
